@@ -72,7 +72,7 @@
 # endif
 #endif
 
-#if defined(_MSC_VER)
+#if defined(_MSC_VER) && (_MSC_VER < 1600)
 typedef __int8 int8_t;
 typedef __int16 int16_t;
 typedef __int32 int32_t;
